# Installation
Depending on if you want only this tool, the full set of PNU tools, or PNU plus a selection of additional third-parties tools, use one of these commands:

pip install [pnu-manpath](https://pypi.org/project/pnu-manpath/)
<br>
pip install [PNU](https://pypi.org/project/PNU/)
<br>
pip install [pytnix](https://pypi.org/project/pytnix/)

# MANPATH(1), MANPATH(3)
This repository includes a command-line utility:
* [manpath(1)](https://github.com/HubTou/manpath/blob/main/MANPATH.1.md) - display search path for manual pages

And a Python library:
* [manpath(3)](https://github.com/HubTou/manpath/blob/main/MANPATH.3.md) - return the search path for manual pages


